2. Electrospray ion-beam deposition — ESIBD Explorer 0.6 documentation

# 2. Electrospray ion-beam deposition

In electrospray ion-beam deposition (ESIBD, also known as soft/reactive landing or preparative mass spectrometry), molecules (small molecules, glycans, peptides, proteins, viruses, …) are transferred from solution to the gas-phase using electrospray ionization to form intense (if required m/z-filtered) molecular ion beams, which are then deposited with well defined energy onto various surfaces in vacuum.1,2,3 It has been successfully enabling high-resolution imaging of complex molecules by scanning probe microscopy4,5,6,7,8,9,10 , transmission electron microscopy11,12,13 , cryo-EM,14,15 and low-energy electron holography.16,17,18 These experiments show that individual peptides, glycans, and proteins can be isolated from a mixture, separated from solvent and contaminants, deposited, and imaged. The ES-IBD approach to sample fabrication has been used to address fundamental questions related to gas-phase structures,17 mechanical properties,8,19 and substrate interactions,20 by direct observation of deformation,8,19 fragmentation,3,8 and assembly at surfaces depending on ion-beam composition,6 substrate,7 and landing energy.17,21

Fig. 2.1 Overview of the Oxford ESIBD setup. Colored boxes highlight selected hardware that is controlled by ESIBD Explorer plugins. Left ESIBD Explorer, current measurement (RBD 9103), voltage supplies and distribution (ISEG ECH 244, ISEG EBS 180 05). Right Deposition stage, independently controlled commercial mass spectrometer (Thermo Scientific TM Q Exactive TM UHMR instrument), temperature measurement (Sunpower CryoTel GTLT), pressure measurement (Edwards TIC, Pfeiffer TPG366). See references for more details. 10,14,15

Figure Fig. 2.1 shows and overview of the Oxford ESIBD setup, which combines a commercial mass spectrometer with a custom deposition stage. Most ESIBD experiments comprise a variety of components including an ion source, ion guides, mass filters, deflectors, focusing lenses, and detectors. They require controlling or monitoring DC potentials, RF amplitudes and frequencies, pressures, temperatures, and ion-beam currents throughout the experimental setup. While each individual device is not very complicated, the number of available parameters that have to be adjusted and documented can quickly result in a massive overhead where researchers spend more time on documentation than on thinking about the science, or even the need to repeat experiments due to incomplete manual documentation. The need for a robust and consistent interface that allows to perform all elements of the ESIBD workflow with only a few clicks, while documenting all relevant information automatically in the background, lead to the creation of the ESIBD Explorer.